@@ -2,11 +2,13 @@
 //! Support for Slack Webhooks methods
 //!
 
+use lazy_static::lazy_static;
 use rsb_derive::Builder;
 use serde::{Deserialize, Serialize};
 use serde_with::skip_serializing_none;
 
 use crate::errors::*;
+use crate::ratectl::*;
 use crate::SlackClient;
 use crate::{ClientResult, SlackClientHttpConnector};
 use slack_morphism_models::*;
@@ -33,6 +35,7 @@ where
                 })?,
                 req,
                 None,
+                Some(&POST_WEBHOOK_SPECIAL_LIMIT_RATE_CTL),
             )
             .await
     }
@@ -49,3 +52,13 @@ pub struct SlackApiPostWebhookMessageRequest {
 #[skip_serializing_none]
 #[derive(Debug, PartialEq, Clone, Serialize, Deserialize, Builder)]
 pub struct SlackApiPostWebhookMessageResponse {}
+
+lazy_static! {
+    pub static ref POST_WEBHOOK_SPECIAL_LIMIT_RATE_CTL: SlackApiMethodRateControlConfig =
+        SlackApiMethodRateControlConfig::new().with_special_rate_limit(
+            SlackApiRateControlSpecialLimit::new(
+                "post_webhook_message".into(),
+                SlackApiRateControlLimit::new(1, std::time::Duration::from_secs(1))
+            )
+        );
+}
